@@ -1,4 +1,4 @@
-use v6.c;
+use v6;
 
 =begin pod
 
@@ -53,7 +53,7 @@ Deserialises the provided JSON string, returning a new object, with the
 public attributes initialised with the corresponding values in the JSON
 structure.
 
-If the JSON is not valid or the data cannot be coerced into the correct 
+If the JSON is not valid or the data cannot be coerced into the correct
 type for the target class then an exception may be thrown.
 
 =head2 method to-json
@@ -74,20 +74,24 @@ though.)
 =end pod
 
 use JSON::Unmarshal;
-use JSON::Marshal:ver(v0.0.6..*);
+use JSON::Marshal:ver(v0.0.7+);
 
-sub EXPORT {
-    { '&trait_mod:<is>'    =>  &trait_mod:<is> }
+my package EXPORT::DEFAULT {
+    OUR::{'&trait_mod:<is>'} := &trait_mod:<is>;
 }
 
-role JSON::Class:ver<0.0.5>:auth<github:jonathanstowe> {
+role JSON::Class:ver<0.0.11>:auth<github:jonathanstowe>:api<1.0> {
 
 
-    method from-json(Str $json) returns JSON::Class {
-        unmarshal($json, self);
+    method from-json(Str $json --> JSON::Class ) {
+        my $ret = unmarshal($json, self);
+        if $ret !~~ JSON::Class {
+            $ret does JSON::Class;
+        }
+        $ret;
     }
 
-    method to-json(Bool :$skip-null) returns Str {
+    method to-json(Bool :$skip-null --> Str ) {
         marshal(self, :$skip-null);
     }
 }
